"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.readFolderPaths = exports.readWorkspaceFolderNames = void 0;
const promises_1 = require("fs/promises");
const path_1 = require("path");
async function readWorkspaceFolderNames() {
    const invalidNameRegExp = /[._]/;
    const folderNames = await (0, promises_1.readdir)(process.cwd(), {
        withFileTypes: true
    });
    const validFolderNames = folderNames.filter((folderName) => !invalidNameRegExp.test(folderName.name) && folderName.isDirectory());
    return validFolderNames.map((folderName) => folderName.name);
}
exports.readWorkspaceFolderNames = readWorkspaceFolderNames;
async function readFolderPaths(folderPath, options) {
    const stats = await (0, promises_1.stat)(folderPath);
    if (!stats.isDirectory()) {
        throw new Error("Folder path is invalid: " + folderPath);
    }
    const allFiles = [];
    for (const name of await (0, promises_1.readdir)(folderPath)) {
        const fullPath = folderPath + path_1.sep + name;
        const stats = await (0, promises_1.stat)(fullPath);
        if (stats.isFile()) {
            allFiles.push(fullPath);
        }
        else if (options.deepSearch && stats.isDirectory()) {
            const deepPaths = await readFolderPaths(fullPath, options);
            allFiles.push(...deepPaths);
        }
    }
    return allFiles;
}
exports.readFolderPaths = readFolderPaths;
